#Licensed Materials - Property of IBM 
#Rational ClearQuest 
#Copyright IBM Corp. 2008 All Rights Reserved 

#!/usr/bin/perl
use Config;
use POSIX qw(locale_h);


BEGIN {
	
}

##############################################################################
#define all file specific global vars
our $DirSep = undef;
our $EnvVarSep = undef;
our $CqcliBin = undef;
our %CmdObj = (	'rational_home' => undef,
				'outdir'		=> undef,
				'script'		=> undef,
				'ja'			=> undef,
				'ch'			=> undef
				);

our %CQCLIEnv = (			'RATIONAL_HOME'					=>	"\" \"",
							'RATIONAL_COMMON'				=>	"\" \"",
							'CLEARQUEST_HOME'				=>	"\" \"",
							'CQCLI_HOME'					=>	"\" \"",
							'CQCLI_DOC_DIR'					=>	"\" \"",
							'CQCLI_MAN_DIR'					=>	"\" \"",
							'CQCLI_CONFIG_DIR'				=>	"\" \"",
							'CQCLI_LIB_DIR'					=>	"\" \"",
							'CQCLI_BIN_DIR'					=>	"\" \"",
							'PERL_INLINE_JAVA_DIRECTORY'	=>  "\" \"",
							'PERL_INLINE_JAVA_JNI'			=>  1,
							'CQCLI_ERR_LEVEL'				=>  1,
							'CLASSPATH'						=>  "\" \"",
							'PATH'							=>  "\" \"",
							'JAVA_HOME'						=>  "\" \"",
							'LD_LIBRARY_PATH'				=>  "\" \"",
							'SHLIB_PATH'							=>  "\" \"",
							'LIBPATH'						=>  "\" \"",
							'J2SDKFILE'						=> "\" \"",
				);


##############################################################################

MAIN();


###############################################################################

sub MAIN()
{
	ParseCmdArgs();
	ValidateCmdArgs();
	ProcessCmdArgs();
	return 1;
}


###############################################################################
sub ParseCmdArgs()
{
	my $cnt = 0;
	my $resltant_value = undef;

	if($#ARGV == -1){
		PrintUsageInfo();
	}
	
	for($cnt = 0; $cnt <=$#ARGV;$cnt++){
		
		if( ($ARGV[$cnt] eq lc("-h")) || ($ARGV[$cnt] eq lc("-help")) ){
			PrintUsageInfo();
		}elsif($ARGV[$cnt] eq lc("-all")){
			$CmdObj{script}= 2;
		}elsif($ARGV[$cnt] eq lc("-envonly")){
			if(!($CmdObj{script}) || ($CmdObj{script} < 2) ){
				$CmdObj{script} = 1;
			}
		}elsif($ARGV[$cnt] eq lc("-outdir")){
			$CmdObj{outdir} = $ARGV[++$cnt];
			if(!(-d $ARGV[$cnt])){
				CreateDir($CmdObj{outdir});
			}
			next;
		}elsif($ARGV[$cnt] eq lc("-rational_home")){
			$CmdObj{rational_home} = $ARGV[++$cnt];
			if(!(-d $CmdObj{rational_home})){
				die "ERROR : invalid directory name for option $ARGV[$cnt]\n\n"
			}
			next;
		}
		elsif($ARGV[$cnt] eq lc("-ja")) {
			$CmdObj{"ja"} = 1;
		}
		elsif($ARGV[$cnt] eq lc("-ch")) {
			$CmdObj{"ch"} = 1;
		}
		elsif($ARGV[$cnt] =~ /.+/){
			print STDERR "ERROR : unrecognised option $ARGV[$cnt]\n\n";
			PrintUsageInfo();
		}
	}

	if(!($CmdObj{script})){
		die "ERROR : please specify mandatory options for this command(see command help [-h])\n\n";
	}

}

sub ValidateCmdArgs()
{
	if(!($CmdObj{script})){
		die "ERROR : please specify mandatory options for this command(see command help [-h])\n\n";
	}

	if(!($CmdObj{outdir})){
		if($Config{osname} eq "MSWin32"){
			$CmdObj{outdir} = "C:\\Program Files\\Rational\\ClearQuest\\cqcli\\bin";
		}else{
			$CmdObj{outdir} = "/opt/rational/clearquest/cqcli/bin";
		}
		print "WARNING : You have not specified the scrpts target output directory in the command options\n\n";
	}
	print "Setting default outdir to $CmdObj{outdir}\n";
	
	if(!($CmdObj{rational_home})){
		if($Config{osname} eq "MSWin32"){
			$CmdObj{rational_home} = "C:\\Program Files\\Rational";
		}else{
			$CmdObj{rational_home} = "/opt/rational";
		}
		print "WARNING : You have not specified the rational_home directory in the command options\n\n";
	}
	print "Setting default rational_home to $CmdObj{rational_home}\n\n";

	if($Config{osname} eq "MSWin32"){
		$CmdObj{rational_home} =~ s/\\{1,}\z//;
		$CmdObj{outdir} =~ s/\\{1,}\z//;
	}else{						#for unix platform
		$CmdObj{rational_home} =~ s/\/{1,}\z//;
		$CmdObj{outdir} =~ s/\\{1,}\z//;
	}

	return 1;
}

sub ProcessCmdArgs()
{
	InitScriptInfo();

	GenerateCQCLIEnv($CQCLIEnv{CQCLI_ENV_SCRIPT});


}


sub PrintUsageInfo()
{
	my $usage = <<EOF;
	Usage:	
		cqperl gencqclienv.pl	[-h] 
					[-rational_home <rational_homedir>] 
					-all|-envonly 
					[-outdir <destination_dir>]|-ja|-zh

		-all will generate env setup script and cqtool wrapper script for the 
		specific platform
		-envonly will only generate env setup script for the specific platform
		(one of -all/-envonly option is mandatory)

		-outdir <destination_dir>
		user can specify the location where the script will be generated.By default 
		it will be generated in cqcli bin directory such as 
								/opt/rational/clearquest/cqcli/bin
		
		-ja Used to set locale on a japanese windows OS (Man pages would be displayed in english if not set)
		
		-ch Used to set locale on a chinese windows OS  (Man pages would be displayed in english if not set)

	Example : 
		if clearquest is installed in c:\\program files\\rational\\clearquest
		or /opt/rational/clearquest
		cqperl gencqcliscript.pl -rational_home c:\\program files\\rational (on windows)
		or
		cqperl gencqcliscript.pl -rational_home /opt/rational/ (on unix platforms)
EOF
	print "$usage";
	exit;

}

###########################################################################################

sub InitScriptInfo()
{
	SetCommonInfo();
	$CQCLIEnv{RATIONAL_HOME} = $CmdObj{rational_home};
	SetEnvForAllOS();
}

sub SetCommonInfo()
{
	if($Config{osname} eq "MSWin32"){
		$DirSep = "\\";
		$EnvVarSep = ";";
	}else{
		$DirSep = "/";
		$EnvVarSep = ":";
	}
}

sub PATHMACRO 
{
	my $path = shift;
	 return $CQCLIEnv{$path};
}

sub PATHMACROVAR 
{
	my $path = shift;
	if($Config{osname} eq "MSWin32"){
		return "%".$path."%";
	}else{
		return "\$"."{".$path."}";
	}
}
	
sub SetEnvForAllOS()
{
	my $locale = "English";
	

	if($Config{osname} eq "MSWin32"){
		$CQCLIEnv{CQCLI_WRAPPER_SCRIPT}=$CmdObj{outdir}.$DirSep."cqtool.bat";
		$CQCLIEnv{CQCLI_ENV_SCRIPT}=$CmdObj{outdir}.$DirSep."cqclienv.bat";

	}else{						#for unix platform
		$CQCLIEnv{CQCLI_WRAPPER_SCRIPT}=$CmdObj{outdir}.$DirSep."cqtool";
		$CQCLIEnv{CQCLI_ENV_SCRIPT}=$CmdObj{outdir}.$DirSep."cqclienv.sh";
	}
	$CQCLIEnv{CQCLI_CMD_SCRIPT}				= $CQCLIEnv{RATIONAL_HOME}.$DirSep."clearquest".$DirSep."cqcli".$DirSep."bin".$DirSep."cqtool.pl";
	$CQCLIEnv{CQPERL_CMD_NAME}				= "cqperl";

	$CQCLIEnv{RATIONAL_COMMON}				= PATHMACRO('RATIONAL_HOME').$DirSep."common";
	$CQCLIEnv{RATIONAL_COMMON_LIB}			= PATHMACRO('RATIONAL_COMMON').$DirSep."lib";
	$CQCLIEnv{CLEARQUEST_HOME}				= PATHMACRO('RATIONAL_HOME').$DirSep."clearquest";
	$CQCLIEnv{CQCLI_HOME}					= PATHMACRO('CLEARQUEST_HOME').$DirSep."cqcli";
	$CQCLIEnv{CQCLI_DOC_DIR}				= PATHMACRO('CQCLI_HOME').$DirSep."doc";
	$CQCLIEnv{CQCLI_CONFIG_DIR}				= PATHMACRO('CQCLI_HOME').$DirSep."config";
	$CQCLIEnv{CQCLI_LIB_DIR}				= PATHMACRO('CQCLI_HOME').$DirSep."lib";
	$CQCLIEnv{CQCLI_BIN_DIR}				= PATHMACRO('CQCLI_HOME').$DirSep."bin";
	$CQCLIEnv{PERL_INLINE_JAVA_DIRECTORY}	= PATHMACRO('CQCLI_LIB_DIR').$DirSep."inlineclass".$DirSep.$Config{archname};
	$CQCLIEnv{PERL_INLINE_JAVA_JNI}			= 1;
	$CQCLIEnv{CQCLI_ERR_LEVEL}				= 1;
				
	if($Config{osname} eq "MSWin32"){
		$CQCLIEnv{JAVA_HOME}					= PATHMACRO('RATIONAL_COMMON').$DirSep."java5.0";
		$CQCLIEnv{JRE_HOME}						= PATHMACRO('RATIONAL_COMMON').$DirSep."java5.0".$DirSep."jre";
	}else{
		$CQCLIEnv{JAVA_HOME}					= PATHMACRO('RATIONAL_COMMON').$DirSep."java";
		$CQCLIEnv{JRE_HOME}						= PATHMACRO('RATIONAL_COMMON').$DirSep."java".$DirSep."jre";
	}
	#$CQCLIEnv{CLASSPATH}					= PATHMACRO('CQCLI_LIB_DIR').$DirSep."cqcli.jar".$EnvVarSep.
	#										  PATHMACRO('CLEARQUEST_HOME').$DirSep."cqjni.jar".$EnvVarSep.
	#										  PATHMACRO('RATIONAL_COMMON').$DirSep."stpcmmn.jar".$EnvVarSep.
	#										  PATHMACRO('RATIONAL_COMMON').$DirSep."stpwvcm.jar".$EnvVarSep.
	#										  PATHMACRO('CLEARQUEST_HOME').$DirSep."stpcq.jar".$EnvVarSep.
	#										  PATHMACRO('CQCLI_CONFIG_DIR').$EnvVarSep.
	#										  PATHMACRO('CLASSPATH');
	$CQCLIEnv{CQCLI_CLASSPATH}				  = PATHMACRO('CQCLI_LIB_DIR').$DirSep."cqcli.jar".$EnvVarSep.
											  PATHMACRO('CQCLI_LIB_DIR').$DirSep."cqjni.jar".$EnvVarSep.
											  PATHMACRO('RATIONAL_COMMON').$DirSep."stpcmmn.jar".$EnvVarSep.
											  PATHMACRO('RATIONAL_COMMON').$DirSep."stpwvcm.jar".$EnvVarSep.
											  PATHMACRO('CLEARQUEST_HOME').$DirSep."stpcq.jar".$EnvVarSep.
											  PATHMACRO('RATIONAL_COMMON'). $DirSep . "jar" . $DirSep . "icu4j-3_8_1.jar".$EnvVarSep.
											  PATHMACRO('CQCLI_CONFIG_DIR').$EnvVarSep.
											  $ENV{'CLASSPATH'};
				
	#set locale specific setting

	$locale = setlocale(LC_CTYPE);
	if(($locale =~ /zh/i) || ($locale =~ /ch/i) ) {
		$CQCLIEnv{CQCLI_MAN_DIR}				= PATHMACRO('CQCLI_DOC_DIR').$DirSep."man".$DirSep."zh";
	}elsif(($locale =~ /ja/i) || ($locale =~ /jap/i)){
		$CQCLIEnv{CQCLI_MAN_DIR}				= PATHMACRO('CQCLI_DOC_DIR').$DirSep."man".$DirSep."ja";
	}else {
		$CQCLIEnv{CQCLI_MAN_DIR}				= PATHMACRO('CQCLI_DOC_DIR').$DirSep."man";
	}

	#set  executable platform specific path	
	if($Config{osname} eq "MSWin32"){
		$CQCLIEnv{CQCLI_PATH}					  = PATHMACRO('CQCLI_BIN_DIR').$EnvVarSep.
												  PATHMACRO('JRE_HOME').$DirSep."bin".$EnvVarSep.
												  #PATHMACRO('JRE_HOME').$DirSep."bin".$DirSep."j9vm".$EnvVarSep.
												  PATHMACRO('JRE_HOME').$DirSep."bin".$DirSep."classic".$EnvVarSep.
												  $ENV{'PATH'};
												  
		if($CmdObj{ch} == 1){
		$CQCLIEnv{CQCLI_MAN_DIR}				= PATHMACRO('CQCLI_DOC_DIR').$DirSep."man".$DirSep."zh";
		}
		elsif($CmdObj{ch} == 1){
		$CQCLIEnv{CQCLI_MAN_DIR}				= PATHMACRO('CQCLI_DOC_DIR').$DirSep."man".$DirSep."ja";
		}
	}elsif($Config{osname} eq "aix"){
		$CQCLIEnv{PATH}							  = PATHMACRO('CQCLI_BIN_DIR').$EnvVarSep.
												  PATHMACRO('JRE_HOME').$DirSep."bin".$EnvVarSep.
												  PATHMACROVAR('PATH');
		$CQCLIEnv{LIBPATH}						  = PATHMACRO('JRE_HOME').$DirSep."bin".$DirSep."j9vm".$EnvVarSep.PATHMACRO('JRE_HOME').$DirSep."bin".$EnvVarSep.
												  #PATHMACRO('JRE_HOME').$DirSep."bin".$DirSep."j9vm".$EnvVarSep.
												  #PATHMACRO('JRE_HOME').$DirSep."bin".$DirSep."classic".$EnvVarSep.
												  PATHMACROVAR('LIBPATH');
	}elsif($Config{osname} eq "hpux") {
		$CQCLIEnv{PATH}							  = PATHMACRO('CQCLI_BIN_DIR').$EnvVarSep.
												  PATHMACRO('JRE_HOME').$DirSep."bin".$EnvVarSep.
												  PATHMACROVAR('PATH');
		$CQCLIEnv{SHLIB_PATH}						  = PATHMACRO('JRE_HOME').$DirSep."lib".$DirSep."PA_RISC2.0".$EnvVarSep. PATHMACRO('JRE_HOME').$DirSep."lib".$DirSep."PA_RISC2.0".$DirSep."shared".$EnvVarSep.PATHMACRO('JRE_HOME').$DirSep."lib".$DirSep."PA_RISC2.0".$DirSep."native_threads".$EnvVarSep.PATHMACRO('JRE_HOME').$DirSep."bin".$EnvVarSep.
												  #PATHMACRO('JRE_HOME').$DirSep."bin".$DirSep."j9vm".$EnvVarSep.
												  #PATHMACRO('JRE_HOME').$DirSep."bin".$DirSep."classic".$EnvVarSep.
												  PATHMACROVAR('SHLIB_PATH');
	}else{
		$CQCLIEnv{PATH}							  = PATHMACRO('CQCLI_BIN_DIR').$EnvVarSep.
												  PATHMACRO('JRE_HOME').$DirSep."bin".$EnvVarSep.
												  PATHMACROVAR('PATH');
		if($Config{osname} eq "linux"){
			$CQCLIEnv{LD_LIBRARY_PATH}				= PATHMACRO('JRE_HOME').$DirSep."bin".$DirSep."j9vm".$EnvVarSep.PATHMACRO('JRE_HOME').$DirSep."bin".$EnvVarSep.
												  #PATHMACRO('JRE_HOME').$DirSep."bin".$DirSep."classic".$EnvVarSep.
												  PATHMACROVAR('LD_LIBRARY_PATH');
		}
		elsif($Config{osname} eq "solaris"){
			$CQCLIEnv{LD_LIBRARY_PATH}				= PATHMACRO('JRE_HOME').$DirSep."lib".$DirSep."sparc".$DirSep."client".$EnvVarSep.PATHMACRO('JRE_HOME').$DirSep."bin".$EnvVarSep.

												  #PATHMACRO('JRE_HOME').$DirSep."bin".$DirSep."classic".$EnvVarSep.
												  PATHMACROVAR('LD_LIBRARY_PATH');
		}
		else{
			$CQCLIEnv{LD_LIBRARY_PATH}				= PATHMACROVAR('JRE_HOME').$DirSep."bin".$DirSep."client".$EnvVarSep.
												  #PATHMACRO('JRE_HOME').$DirSep."bin".$DirSep."classic".$EnvVarSep.
												  PATHMACROVAR('LD_LIBRARY_PATH');
		}
	}

	return 1;
}

sub GenerateCQCLIEnv()
{
	my $file = shift;
	if($Config{osname} eq "MSWin32"){
		GenerateCQCLIEnvWindows($file);
	}else {
		GenerateCQCLIEnvUnix($file);
		my $cshfile = "cqclienv.csh";
		GenerateCQCLIEnvUnixForCshell($cshfile);
	}

	return 1;
}

sub GenerateCQCLIScript()
{
	my $file = shift;
	if($Config{osname} eq "MSWin32"){
		GenerateCQCLIScriptWindows($file);
	}else {
		GenerateCQCLIScriptUnix($file);
	}

	return 1;
}

sub GenerateCQCLIEnvWindows
{
	my $file = shift;
	my $script = shift;
	BackupFile($file);
	open (FH,">$file") or die "File $file can not be created\n" ;
	local *OLDFH = *STDOUT;
	local *STDOUT = *FH;

	#write all settings to the file
	print "\@ECHO OFF"."\n\n";
	if(!($script)){
		#print "IF NOT \"\%CQCLI_ENV_ALL\%\"==\"\" GOTO ALLREADYSET\n";
	
		print "set RATIONAL_HOME=$CQCLIEnv{RATIONAL_HOME}"."\n";
		print "set RATIONAL_COMMON=$CQCLIEnv{RATIONAL_COMMON}"."\n";
		print "set RATIONAL_COMMON_LIB=$CQCLIEnv{RATIONAL_COMMON_LIB}"."\n";
		print "set CLEARQUEST_HOME=$CQCLIEnv{CLEARQUEST_HOME}"."\n";
		print "set CQCLI_HOME=$CQCLIEnv{CQCLI_HOME}"."\n";
		print "set CQCLI_DOC_DIR=$CQCLIEnv{CQCLI_DOC_DIR}"."\n";
		print "set CQCLI_CONFIG_DIR=$CQCLIEnv{CQCLI_CONFIG_DIR}"."\n";
		print "set CQCLI_LIB_DIR=$CQCLIEnv{CQCLI_LIB_DIR}"."\n";
		print "set CQCLI_BIN_DIR=$CQCLIEnv{CQCLI_BIN_DIR}"."\n";
		print "set CQCLI_MAN_DIR=$CQCLIEnv{CQCLI_MAN_DIR}"."\n";
		print "set CQCLI_ERR_LEVEL=$CQCLIEnv{CQCLI_ERR_LEVEL}"."\n";
		print "\n";
		#print "set PERL_INLINE_JAVA_DIRECTORY=$CQCLIEnv{PERL_INLINE_JAVA_DIRECTORY}"."\n";
		print "set PERL_INLINE_JAVA_JNI=$CQCLIEnv{PERL_INLINE_JAVA_JNI}"."\n";
		print "set JAVA_HOME=$CQCLIEnv{JAVA_HOME}"."\n";
		print "set JRE_HOME=$CQCLIEnv{JRE_HOME}"."\n";
		print "set CQCLI_CLASSPATH=$CQCLIEnv{CQCLI_CLASSPATH}"."\n";
		print "set CQCLI_PATH=$CQCLIEnv{CQCLI_PATH}"."\n";
		print "set CQCLI_ENV_ALL=1"."\n";
		print "\n\n";
		print "REM you can add your specific environment here\n\n";
	}

	#restore back the STDOUT
	close(FH);
	*STDOUT=*OLDFH;
	chmod(0777,$file);

}

sub GenerateCQCLIEnvUnix
{
	my ($file,$script) = @_;	
	BackupFile($file);
	open (FH,">$file") or die "File $file can not be created\n" ;
	local *OLDFH = *STDOUT;
	local *STDOUT = *FH;

	#write all settings to the file
	#write all settings to the file
	print "#!/bin/sh\n\n";
	if(!($script)){
		#print "if [ \"\$CQCLI_ENV_ALL\" = \"\" ]; then\n"
	
		print "export RATIONAL_HOME=$CQCLIEnv{RATIONAL_HOME}"."\n";
		print "export RATIONAL_COMMON=$CQCLIEnv{RATIONAL_COMMON}"."\n";
		print "export RATIONAL_COMMON_LIB=$CQCLIEnv{RATIONAL_COMMON_LIB}"."\n";
		print "export CLEARQUEST_HOME=$CQCLIEnv{CLEARQUEST_HOME}"."\n";
		print "export CQCLI_HOME=$CQCLIEnv{CQCLI_HOME}"."\n";
		print "export CQCLI_DOC_DIR=$CQCLIEnv{CQCLI_DOC_DIR}"."\n";
		print "export CQCLI_CONFIG_DIR=$CQCLIEnv{CQCLI_CONFIG_DIR}"."\n";
		print "export CQCLI_LIB_DIR=$CQCLIEnv{CQCLI_LIB_DIR}"."\n";
		print "export CQCLI_BIN_DIR=$CQCLIEnv{CQCLI_BIN_DIR}"."\n";
		print "export CQCLI_MAN_DIR=$CQCLIEnv{CQCLI_MAN_DIR}"."\n";
		print "export CQCLI_ERR_LEVEL=$CQCLIEnv{CQCLI_ERR_LEVEL}"."\n";
		print "\n";
		#print "export PERL_INLINE_JAVA_DIRECTORY=$CQCLIEnv{PERL_INLINE_JAVA_DIRECTORY}"."\n";
		print "export PERL_INLINE_JAVA_JNI=$CQCLIEnv{PERL_INLINE_JAVA_JNI}"."\n";
		print "export JAVA_HOME=$CQCLIEnv{JAVA_HOME}"."\n";
		print "export JRE_HOME=$CQCLIEnv{JRE_HOME}"."\n";
		print "export CLASSPATH=$CQCLIEnv{CQCLI_CLASSPATH}:${CLASSPATH}"."\n";
		print "export PATH=$CQCLIEnv{PATH}"."\n";
		if($Config{osname} eq "aix"){
			print "export LIBPATH=$CQCLIEnv{LIBPATH}"."\n";
		}elsif($Config{osname} eq "hpux") {
			# USing the client server mode 
			print "export PERL_INLINE_JAVA_JNI=0" . "\n";
			print "export PERL_INLINE_JAVA_J2SDK=$CQCLIEnv{JRE_HOME}"."\n";
			print "export SHLIB_PATH=$CQCLIEnv{SHLIB_PATH}"."\n";
		}else{
			print "export LD_LIBRARY_PATH=$CQCLIEnv{LD_LIBRARY_PATH}"."\n";
		}
		print "export CQCLI_ENV_ALL=1"."\n";
		print "\n\n";
		print "# you can add your specific environment here\n";
		print "echo \"You can now run 'cqtool'\"\n";
	}
	if($script){
		#print "fi\n\n";
		print "$CQCLIEnv{CQPERL_CMD_NAME}  $CQCLIEnv{CQCLI_CMD_SCRIPT} \$* \n";
	}



	#restore back the STDOUT
	close(FH);
	*STDOUT=*OLDFH;
	chmod(0777,$file);

}

sub GenerateCQCLIEnvUnixForCshell
{
	my ($file,$script) = @_;	
	BackupFile($file);
	open (FH,">$file") or die "File $file can not be created\n" ;
	local *OLDFH = *STDOUT;
	local *STDOUT = *FH;

	#write all settings to the file
	#write all settings to the file
	print "#!/bin/csh\n\n";
	if(!($script)){
		#print "if [ \"\$CQCLI_ENV_ALL\" = \"\" ]; then\n"
	
		print "setenv RATIONAL_HOME $CQCLIEnv{RATIONAL_HOME}"."\n";
		print "setenv RATIONAL_COMMON $CQCLIEnv{RATIONAL_COMMON}"."\n";
		print "setenv RATIONAL_COMMON_LIB $CQCLIEnv{RATIONAL_COMMON_LIB}"."\n";
		print "setenv CLEARQUEST_HOME $CQCLIEnv{CLEARQUEST_HOME}"."\n";
		print "setenv CQCLI_HOME $CQCLIEnv{CQCLI_HOME}"."\n";
		print "setenv CQCLI_DOC_DIR $CQCLIEnv{CQCLI_DOC_DIR}"."\n";
		print "setenv CQCLI_CONFIG_DIR $CQCLIEnv{CQCLI_CONFIG_DIR}"."\n";
		print "setenv CQCLI_LIB_DIR $CQCLIEnv{CQCLI_LIB_DIR}"."\n";
		print "setenv CQCLI_BIN_DIR $CQCLIEnv{CQCLI_BIN_DIR}"."\n";
		print "setenv CQCLI_MAN_DIR $CQCLIEnv{CQCLI_MAN_DIR}"."\n";
		print "setenv CQCLI_ERR_LEVEL $CQCLIEnv{CQCLI_ERR_LEVEL}"."\n";
		print "\n";
		#print "export PERL_INLINE_JAVA_DIRECTORY=$CQCLIEnv{PERL_INLINE_JAVA_DIRECTORY}"."\n";
		print "setenv PERL_INLINE_JAVA_JNI $CQCLIEnv{PERL_INLINE_JAVA_JNI}"."\n";
		print "setenv JAVA_HOME $CQCLIEnv{JAVA_HOME}"."\n";
		print "setenv JRE_HOME $CQCLIEnv{JRE_HOME}"."\n";
		print "setenv CLASSPATH $CQCLIEnv{CQCLI_CLASSPATH}:${CLASSPATH}"."\n";
		print "setenv PATH $CQCLIEnv{PATH}"."\n";
		if($Config{osname} eq "aix"){
			print "setenv LIBPATH $CQCLIEnv{LIBPATH}"."\n";
		}elsif($Config{osname} eq "hpux") {
			print "setenv PERL_INLINE_JAVA_JNI 0" . "\n";
			print "setenv PERL_INLINE_JAVA_J2SDK $CQCLIEnv{JRE_HOME}"."\n";
			print "setenv SHLIB_PATH $CQCLIEnv{SHLIB_PATH}"."\n";
		}else{
			print "setenv LD_LIBRARY_PATH $CQCLIEnv{LD_LIBRARY_PATH}"."\n";
		}
		print "setenv CQCLI_ENV_ALL 1"."\n";
		print "\n\n";
		print "# you can add your specific environment here\n";
		print "echo \"You can now run 'cqtool'\"\n";
	}
	if($script){
		#print "fi\n\n";
		print "$CQCLIEnv{CQPERL_CMD_NAME}  $CQCLIEnv{CQCLI_CMD_SCRIPT} \$* \n";
	}



	#restore back the STDOUT
	close(FH);
	*STDOUT=*OLDFH;
	chmod(0777,$file);
}

sub GenerateCQCLIScriptWindows
{
	my $file = shift;
	GenerateCQCLIEnvWindows($file,1);
	return 1;
	
}

sub GenerateCQCLIScriptUnix
{
	my $file = shift;
	GenerateCQCLIEnvUnix($file,1);
	my $cshfile = "cqclienv.csh";
	GenerateCQCLIEnvUnixForCshell($cshfile,1);
	return 1;
}

sub BackupFile()
{
	my $file = shift;
	my $filebak = $file."\."."bak";
	if(-e $file){
		if(-e $filebak){
			unlink $filebak;
		}
		rename $file , $filebak;
	}
	return 1;
}

sub CreateDir()
{
	my $dirname = shift;

	if($Config{osname} eq "MSWin32"){
			if(!(system("mkdir  \"$dirname\""))){
				goto ERROR;
			}
			return 1;
	}else{
		if(system("mkdir -p \"$dirname\"")){
			goto ERROR;
		}
		return 1;
	}

	ERROR :
		print "please create manually  directory $CmdObj{outdir} before you run this command\n";
		exit;
		
}
